import recordlinkage.config as cf
from recordlinkage.config import get_default_val
from recordlinkage.config import is_bool
from recordlinkage.config import is_callable
from recordlinkage.config import is_instance_factory
from recordlinkage.config import is_int
from recordlinkage.config import is_one_of_factory
from recordlinkage.config import is_text

pairs_type_doc = """
: str
    Specify the format how record pairs are stored. By default, record
    pairs generated by the toolkit are returned in a
    pandas.MultiIndex object ('multiindex' option).

    Valid values: 'multiindex'
"""

classification_return_type_doc = """
: str
    The format of the classification result. The value 'index' returns the
    classification result as a pandas.MultiIndex. The MultiIndex contains
    the predicted matching record pairs. The value 'series' returns a
    pandas.Series with zeros (distinct) and ones (matches). The argument
    value 'array' will return a numpy.ndarray with zeros and ones.

"""

with cf.config_prefix('indexing'):
    cf.register_option('pairs',
                       'multiindex',
                       pairs_type_doc,
                       validator=is_one_of_factory(['multiindex']))

with cf.config_prefix('classification'):
    cf.register_option('return_type',
                       'index',
                       classification_return_type_doc,
                       validator=is_one_of_factory(
                           ['index', 'series', 'array']))
